@@ -1,4 +1,7 @@
 from .authentication_failed import AuthenticationFailed
+from .invalid_session import InvalidSession
+from .invalid_extension import InvalidExtension
+from .not_authenticated import NotAuthenticated
 from .not_found import NotFound
 from .permission_denied import PermissionDenied
 from .too_many_request import TooManyRequest
